@import 'https://fonts.googleapis.com/css?family=Lato:400,700';

body {
  font-family: 'Lato', sans-serif;
  overflow-y: scroll;
  background-color: #f5f5f5;
  padding-bottom: 5em;
}

input[type=checkbox], input[type=radio] {
  vertical-align: middle;
  position: relative;
}

.pagination ul > li:not(.disabled) {
  cursor: pointer;
}

.pagination ul > li.active > a {
  color: #fff;
  background-color: #428bca;
}

.label-active, .badge-active, .progress-active .bar {
  background-color: #62C462;
}

.progress-success .bar {
  background-color: #468847 !important;
}

.alerts {
  position: fixed;
  right: 6px;
  z-index: 900;
  width: 40%;
}

.alert {
  float: right;
  clear: right;
  margin-bottom: 5px;
  margin-top: 5px;
}

/* fix modal overflow on low resolutions */
.modal {
  position: absolute;
}

#global-graph {
  width: 100%;
}

@media (min-width: 767px) and (max-width: 992px) {
  #global-graph {
    width: 80%;
  }
}

#download-filter {
  margin: 0;
  height: auto;
}

#filters label {
  display: inline-block;
  white-space: nowrap;
}

.nav-header {
  display: block;
  padding: 3px 0;
  font-size: 11px;
  font-weight: bold;
  line-height: 20px;
  color: #999;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
  text-transform: uppercase;
}

.main-navbar {
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.1);
  background-color: #00897B;
  border-color: #00897B;
}

.main-navbar .navbar-brand {
  color: #fff;
}

.main-navbar .nav > li > a {
  color: #fff;
  transition: background-color 0.3s ease-in-out;
}

.main-navbar .navbar-toggle .icon-bar {
  background-color: #fff;
}

.main-navbar.nav .open > a,
.main-navbar.nav .open > a:hover,
.main-navbar.nav .open > a:focus,
.main-navbar .nav > li > a:focus,
.main-navbar .nav > li > a:hover {
  background-color: rgba(0, 0, 0, 0.2);
}

.sidebar-nav {
  margin-bottom: 30px;
  background-color: #fff;
  padding: 10px 20px 20px;
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 2px 1px -1px rgba(0, 0, 0, 0.12);
}

.filter-input-group {
  position: relative;
  margin-bottom: 30px;
}

.filter-input-group > .clear-button {
  position: absolute;
  right: 25px;
  top: 6px;  
  cursor: pointer;
}