if(typeof translations == 'undefined'){
    translations = {};
}

translations.fa_IR = {
// header
    'Search': 'جستجو',
    // Nav menu
    'Add': 'اضافه کردن',
    'By URIs': 'بر اساس مسیر سایت',
    'By Torrents': 'بر اساس تورنت',
    'By Metalinks': 'بر اساس متا لینک',
    'Manage': 'مدیریت',
    'Pause All': 'توقف همه',
    'Resume Paused': 'ادامه متوقف شده ها',
    'Purge Completed': 'حذف تکمیل شده ها',
    'Shutdown Server': 'خاموش کردن سرور',
    'Settings': 'تنظیمات',
    'Connection Settings': 'تنظیمات ارتباط',
    'Global Settings': 'تنظیمات سراسری',
    'Server info': 'اطلاعات سرور',
    'About and contribute': 'درباره و مشارکت',
    'Toggle navigation': 'تغییر ناوبری',
// body
// nav side bar
    'Miscellaneous': 'متفرقه',
    'Global Statistics': 'آمار سراسری',
    'About': 'درباره',
    'Displaying': 'نمایش',
    'of': 'از',
    'downloads': 'دانلودها',
    'Language': 'زبان',
// download filters
    'Download Filters': 'دانلود فیلترها',
    'Running': 'در حال اجرا',
    'Active': 'فعال',
    'Waiting': 'در انتظار',
    'Complete': 'تمام شده',
    'Error': 'خطا',
    'Paused': 'متوقف شده',
    'Removed': 'حذف شده',
    'Hide linked meta-data': 'مخفی کردن متا داده مرتبط',
    'Toggle': 'تغییر وضعیت',
    'Reset filters': 'حذف فیلترها',
// download status
    'Verifing': 'تأیید کردن',
    'Verify Pending': 'تأیید کردن در انتظارها',
// starred properties
    'Quick Access Settings': 'تنظیمات دسترسی سریع',
    'Save': 'ذخیره',
    'Save settings': 'ذخیره تنظیمات',
    'Currently no download in line to display, use the': 'در حال حاضر هیچ دانلودی برای نمایش وجود ندارد، استفاده از',
    'download button to start downloading files!': 'دکمه دانلود برای شروع دانلود فایل ها!',
    'Peers': 'همتایان',
    'More Info': 'اطلاعات بیشتر',
    'Remove': 'حذف',
    '# of': 'از #',
    'Length': 'طول',
// modals
    'Add Downloads By URIs': 'اضافه کردن دانلود توسط لینک ها',
    '- You can add multiple downloads (files) at the same time by putting URIs for each file on a separate line.':
        '- شما می توانید چند بار دانلود (فایل ها) را همزمان با قرار دادن URI ها برای هر فایل در یک خط جداگانه اضافه کنید.',
    '- You can also add multiple URIs (mirrors) for the *same* file. To do this, separate the URIs by a space.':
        '- شما همچنین می توانید URI های متعدد (آینه ها) را برای فایل *همان* اضافه کنید. برای انجام این کار، URI ها را با یک فضای جداگانه جدا کنید.',
    '- A URI can be HTTP(S)/FTP/BitTorrent-Magnet.': '- یک URI می تواند HTTP (S) / FTP / BitTorrent-Magnet باشد.',
    'Download settings': 'تنظیمات دانلود',
    'Advanced settings': 'تنظیمات پیشرفته',
    'Cancel': 'لغو',
    'Start': 'شروع',
    'Choose': 'انتخاب',
    'Quick Access (shown on the main page)': 'دسترسی سریع (نشان داده شده در صفحه اصلی)',
// add torrent modal
    'Add Downloads By Torrents': 'اضافه کردن دانلود توسط تورنت',
    '- Select the torrent from the local filesystem to start the download.': '- تورنت را از سیستم فایل محلی انتخاب کنید تا دانلود را شروع کنید.',
    '- You can select multiple torrents to start multiple downloads.': '- شما می توانید چندین تورنت را برای شروع بارگیری چندگانه انتخاب کنید.',
    '- To add a BitTorrent-Magnet URL, use the Add By URI option and add it there.': '- برای اضافه کردن URL BitTorrent-Magnet، از گزینه بر اساس مسیر سایت استفاده کنید و آن را در آنجا اضافه کنید.',
    'Select Torrents': 'تورنت ها را انتخاب کنید',
    'Select a Torrent': 'تورنتی را انتخاب کنید',
// add metalink modal
    'Add Downloads By Metalinks': 'متالینک ها را انتخاب کنید',
    'Select Metalinks': 'Metalinks را انتخاب کنید',
    '- Select the Metalink from the local filesystem to start the download.': '- Metalink را از سیستم فایل محلی انتخاب کنید تا دانلود را شروع کنید.',
    '- You can select multiple Metalinks to start multiple downloads.': '- شما می توانید چندین Metalinks را برای شروع چندین بار انتخاب کنید.',
    'Select a Metalink': 'Metalink را انتخاب کنید',
// select file modal
    'Choose files to start download for': 'فایل را برای شروع دانلود انتخاب کنید',
    'Select to download': 'برای دانلود انتخاب کنید',
// settings modal
    'Aria2 RPC host and port': 'میزبان و پورت Aria2 RPC',
    'Enter the host': 'میزبان را وارد کنید',
    'Enter the IP or DNS name of the server on which the RPC for Aria2 is running (default: localhost)':
        'نام IP یا DNS سرور که RPC برای Aria2 در حال اجرا است را وارد کنید (به طور پیش فرض: localhost)',
    'Enter the port': 'پورت را وارد کنید',
    'Enter the port of the server on which the RPC for Aria2 is running (default: 6800)':
        'پورت سرور که RPC برای Aria2 اجرا می شود را وارد کنید (به طور پیش فرض: 6800)',
    'Enter the RPC path': 'مسیر RPC را وارد کنید',
    'Enter the path for the Aria2 RPC endpoint (default: /jsonrpc)': 'مسیر نقطه پایانی Aria2 RPC را وارد کنید (default: / jsonrpc)',
    'SSL/TLS encryption': 'SSL / TLS رمزگذاری',
    'Enable SSL/TLS encryption': 'SSL / TLS رمزگذاری را فعال کنید',
    'Enter the secret token (optional)': 'رمز نشانه (اختیاری) را وارد کنید',
    'Enter the Aria2 RPC secret token (leave empty if authentication is not enabled)':
        'کد مخفی Aria2 RPC را وارد کنید (اگر احراز هویت فعال نمی شود خالی بگذارید)',
    'Enter the username (optional)': 'نام کاربری (اختیاری) را وارد کنید',
    'Enter the Aria2 RPC username (empty if authentication not enabled)':
        'نام کاربری Aria2 RPC را وارد کنید (خالی اگر احراز هویت غیر فعال شود)',
    'Enter the password (optional)': 'رمز عبور را وارد کنید (اختیاری)',
    'Enter the Aria2 RPC password (empty if authentication not enabled)': 'گذرواژه Aria2 RPC را وارد کنید (اگر احراز هویت فعال نمی شود خالی بگذارید)',
    'Enter base URL (optional)': 'URL پایه را وارد کنید (اختیاری)',
    'Direct Download': 'دانلود مستقیم',
    'If supplied, links will be created to enable direct download from the Aria2 server.':
        'در صورت عرضه، لینک برای ایجاد مستقیم دانلود از سرور Aria2 ایجاد خواهد شد.',
    '(Requires appropriate webserver to be configured.)': '(نیاز به وب سرور مناسب برای پیکربندی.)',
    'Save Connection configuration': 'ذخیره پیکربندی اتصال',
    'Filter': 'فیلتر',
// server info modal
    'Aria2 server info': 'مشخصات سرور Aria2',
    'Aria2 Version': 'نسخه Aria2',
    'Features Enabled': 'ویژگی های فعال',
// about modal
    'To download the latest version of the project, add issues or to contribute back, head on to':
        'برای دانلود آخرين نسخه پروژه، مسائل را اضافه کنيد يا به پشتيبانی بپردازيد بروید به',
    'Or you can open the latest version in the browser through': 'یا شما می توانید آخرین نسخه را از طریق مرورگر باز کنید',
    'Close': 'بستن',
// labels
    'Download status':'وضعیت دانلود',
    'Download Speed':'سرعت دانلود',
    'Upload Speed':'سرعت آپلود',
    'Estimated time':'زمان تخمین زده شده',
    'Download Size':'اندازه دانلود',
    'Downloaded':'دانلود شده',
    'Progress':'پیشرفت',
    'Download Path':'مسیر دانلود',
    'Uploaded':'آپلود شده',
    'Download GID':'دانلود GID',
    'Number of Pieces':'تعداد قطعات',
    'Piece Length':'طول قطعه',

//alerts
    'The last connection attempt was unsuccessful. Trying another configuration': 
        'آخرین تلاش اتصال ناموفق بود. تلاش برای تنظیم دیگر',
    'Oh Snap!': 'اوه نه!',
    'Could not connect to the aria2 RPC server. Will retry in 10 secs. You might want to check the connection settings by going to Settings > Connection Settings':
        'نمی توان به سرور aria2 RPC متصل شد. در 10 ثانیه دوباره تلاش خواهیم کرد ممکن است بخواهید تنظیمات اتصال را با رفتن به تنظیمات > تنظیمات اتصال بررسی کنید',
    'Authentication failed while connecting to Aria2 RPC server. Will retry in 10 secs. You might want to confirm your authentication details by going to Settings > Connection Settings':
        'در هنگام اتصال به سرور Aria2 RPC تأییدیه شکست خورد. در 10 ثانیه دوباره تلاش خواهیم کرد ممکن است بخواهید جزئیات احراز هویت خود را با رفتن به تنظیمات > تنظیمات اتصال تایید کنید',
    'Successfully connected to Aria2 through its remote RPC …':
        'با موفقیت از طریق RPC از راه دور به Aria2 متصل شد ...',
    'Successfully connected to Aria2 through remote RPC, however the connection is still insecure. For complete security try adding an authorization secret token while starting Aria2 (through the flag --rpc-secret)':
        'با موفقیت به Aria2 از طریق RPC راه دور متصل شد، اما اتصال هنوز ناامن است. برای امنیت کامل سعی کنید مجوز نشانه مجوز را در هنگام شروع Aria2 (از طریق پرچم --rpc-secret)',
    'Trying to connect to aria2 using the new connection configuration':
        'تلاش برای اتصال به aria2 با استفاده از پیکربندی اتصال جدید',
    'Remove {{name}} and associated meta-data?':
        'حذف {{name}} و متا داده های مرتبط'
};
